package com.virtual.plat.server;

import com.virtual.common.AppException;
import com.virtual.common.FuncUtil;
import com.virtual.plat.server.RequestData;
import com.virtual.plat.server.RequestHandler;
import com.virtual.plat.server.backupCIC.CICBackupHandler;
import com.virtual.plat.server.cloudos.CloudOSHandler;
import com.virtual.plat.server.cluster.ClusterHandler;
import com.virtual.plat.server.host.HostHandler;
import com.virtual.plat.server.ldap.LdapHandler;
import com.virtual.plat.server.message.MessageMgr;
import com.virtual.plat.server.publiccloud.CasVmHandler;
import com.virtual.plat.server.restore.BackupAndRestoreHandler;
import com.virtual.plat.server.storage.StorageHandler;
import com.virtual.plat.server.virtualhost.DomainHandler;
import java.util.Date;
import java.util.Map;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class CommonRequestProcessor implements Runnable {

   private static Log log = LogFactory.getLog(CommonRequestProcessor.class);
   private DomainHandler domainHandler = null;
   private ClusterHandler clusterHandler = null;
   private StorageHandler storageHandler = null;
   protected LdapHandler ldapHandler = null;
   private HostHandler hostHandler = null;
   private BackupAndRestoreHandler backupHandler = null;
   private CasVmHandler casVmHandler = null;
   private MessageMgr messageMgr = null;
   private CloudOSHandler cloudOSHandler;
   private RequestData reqData = null;
   private CICBackupHandler cicBackupHandler = null;


   public CommonRequestProcessor(RequestHandler var1, RequestData var2) {
      this.domainHandler = var1.domainHandler;
      this.backupHandler = var1.backupHandler;
      this.clusterHandler = var1.clusterHandler;
      this.storageHandler = var1.storageHandler;
      this.hostHandler = var1.hostHandler;
      this.ldapHandler = var1.ldapHandler;
      this.messageMgr = var1.messageMgr;
      this.casVmHandler = var1.casVmHandler;
      this.cloudOSHandler = var1.cloudOSHandler;
      this.cicBackupHandler = var1.cicBackupHandler;
      this.reqData = var2;
   }

   public void run() {
      try {
         log.info("Request type:" + FuncUtil.convertTaskType(this.reqData.getRequestType()));
         this.messageMgr.updateMessage(this.reqData.getMessageId(), new Date());
         Map var1 = this.reqData.getData().getProperties();
         switch(this.reqData.getRequestType()) {
         case 1:
         case 3:
         case 4:
         case 12:
         case 13:
         case 15:
         case 17:
         case 18:
         case 20:
         case 22:
         case 23:
         case 24:
         case 30:
         case 31:
         case 32:
         case 33:
         case 34:
         case 35:
         case 36:
         case 37:
         case 38:
         case 45:
         case 63:
         case 67:
         case 68:
         case 69:
         case 171:
         case 172:
            break;
         case 2:
            this.clusterHandler.deleteCluster(this.reqData);
            break;
         case 5:
            this.clusterHandler.editHa(this.reqData);
            break;
         case 6:
            this.clusterHandler.addDmain(this.reqData);
            break;
         case 10:
            this.hostHandler.addHost(this.reqData);
            break;
         case 11:
            this.hostHandler.deleteHost(this.reqData);
            break;
         case 14:
            this.hostHandler.restoreClusterHost(this.reqData);
            break;
         case 16:
            this.hostHandler.restoreOCFS2(this.reqData);
            break;
         case 21:
            this.domainHandler.deleteDomain(this.reqData);
            break;
         case 25:
            this.domainHandler.modifyDomainDevice(this.reqData);
            break;
         case 26:
            this.domainHandler.repairVm(this.reqData);
            break;
         case 40:
            this.backupHandler.backup(this.reqData);
            break;
         case 41:
            this.backupHandler.restore(this.reqData);
            break;
         case 42:
            this.domainHandler.snapShotDomain(this.reqData);
            break;
         case 43:
            this.domainHandler.deleteSnapShot(this.reqData);
            break;
         case 44:
            this.domainHandler.resumeFromSnapshot(this.reqData);
            break;
         case 47:
            Integer var2 = null;
            if(var1.get("cloudType") != null) {
               var2 = Integer.valueOf(var1.get("cloudType").toString());
            }

            if(var2 != null && var2.intValue() != 2) {
               this.cloudOSHandler.deployDomain(this.reqData);
            } else {
               this.domainHandler.deployDomain(this.reqData);
            }
            break;
         case 58:
            this.domainHandler.modifyDomainBasicInfo(this.reqData);
            break;
         case 60:
            this.backupHandler.backupToCAS(this.reqData);
            break;
         case 61:
            this.backupHandler.restoreFromCAS(this.reqData);
            break;
         case 66:
            this.casVmHandler.vmLocalization(this.reqData);
            break;
         case 74:
            this.backupHandler.importHistory(this.reqData);
            break;
         case 102:
            this.storageHandler.copyVolToCvk(this.reqData);
            break;
         case 103:
            this.domainHandler.restoreFromRecycleBin(this.reqData);
            break;
         case 174:
            this.cicBackupHandler.backupCIC(this.reqData);
            break;
         case 175:
            this.domainHandler.handleVmHA(this.reqData);
            break;
         case 177:
            this.cicBackupHandler.importCICBackupHistory(this.reqData);
         case 180:
            this.storageHandler.formatOCFS2Disk(this.reqData);
            break;
         case 2000:
            this.cloudOSHandler.cloudOSOperateListen(this.reqData);
            break;
         default:
            return;
         }
      } catch (AppException var3) {
         log.error((Object)null, var3);
         return;
      } catch (Exception var4) {
         log.error((Object)null, var4);
      }

   }

}
